pub struct CodeTaskDetailsResponse {
pub current_user_turn: Option<Turn>,
pub current_assistant_turn: Option<Turn>,
pub current_diff_task_turn: Option<Turn>,
}Expand description
Hand-rolled models for the Cloud Tasks task-details response. The generated OpenAPI models are pretty bad. This is a half-step towards hand-rolling them.
Fields
current_user_turn: Option<Turn>current_assistant_turn: Option<Turn>current_diff_task_turn: Option<Turn>Trait Implementations
Sourceimpl Clone for CodeTaskDetailsResponse
impl Clone for CodeTaskDetailsResponse
Sourcefn clone(&self) -> CodeTaskDetailsResponse
fn clone(&self) -> CodeTaskDetailsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CodeTaskDetailsResponseExt for CodeTaskDetailsResponse
impl CodeTaskDetailsResponseExt for CodeTaskDetailsResponse
Sourcefn unified_diff(&self) -> Option<String>
fn unified_diff(&self) -> Option<String>
Attempt to extract a unified diff string from the assistant or diff turn.
Sourcefn assistant_text_messages(&self) -> Vec<String>
fn assistant_text_messages(&self) -> Vec<String>
Extract assistant text output messages (no diff) from current turns.
Sourcefn user_text_prompt(&self) -> Option<String>
fn user_text_prompt(&self) -> Option<String>
Extract the user’s prompt text from the current user turn, when present.
Sourcefn assistant_error_message(&self) -> Option<String>
fn assistant_error_message(&self) -> Option<String>
Extract an assistant error message (if the turn failed and provided one).
Sourceimpl Debug for CodeTaskDetailsResponse
impl Debug for CodeTaskDetailsResponse
Sourceimpl<'de> Deserialize<'de> for CodeTaskDetailsResponse
impl<'de> Deserialize<'de> for CodeTaskDetailsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more