CodeTaskDetailsResponseExt

Trait CodeTaskDetailsResponseExt 

pub trait CodeTaskDetailsResponseExt {
    // Required methods
    fn unified_diff(&self) -> Option<String>;
    fn assistant_text_messages(&self) -> Vec<String>;
    fn user_text_prompt(&self) -> Option<String>;
    fn assistant_error_message(&self) -> Option<String>;
}

Required Methods

fn unified_diff(&self) -> Option<String>

Attempt to extract a unified diff string from the assistant or diff turn.

fn assistant_text_messages(&self) -> Vec<String>

Extract assistant text output messages (no diff) from current turns.

fn user_text_prompt(&self) -> Option<String>

Extract the user’s prompt text from the current user turn, when present.

fn assistant_error_message(&self) -> Option<String>

Extract an assistant error message (if the turn failed and provided one).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors